# res-msg

一个简单的Python包，用于演示Python虚拟环境和包管理工具。

## 安装

使用uv工具安装：

```bash
uv pip install -e .
```

或使用pip安装：

```bash
pip install -e .
```

## 使用方法

### 命令行

```bash
# 显示问候语
res-msg

# 指定名称显示问候语
res-msg --name "Your Name"

# 调用API示例
res-msg --api

# 显示Python版本
res-msg --version
```

### 作为库使用

```python
from res_msg import greet, get_simple_api, get_python_version

# 显示问候语
print(greet("Your Name"))

# 调用API
print(get_simple_api())

# 获取Python版本
print(get_python_version())
```

## 项目结构

```
res-msg/
├── main.py              # 主入口文件
├── pyproject.toml       # 项目配置文件
├── README.md            # 项目说明文件
└── src/                 # 源代码目录
    └── res_msg/         # 包目录
        ├── __init__.py  # 包初始化文件
        └── cli.py       # 命令行接口
```

## 依赖

- Python >= 3.11
- requests >= 2.32.3

## 许可证

MIT

## 测试

本项目使用 pytest 进行测试。以下是运行测试的方法：

### 安装测试依赖

```bash
# 安装项目和测试依赖
uv pip install -e ".[dev]"
```

### 运行测试

```bash
# 使用便捷脚本运行测试
./run_tests.sh

# 或者直接使用 pytest
python -m pytest
```

### 生成代码覆盖率报告

```bash
# 使用便捷脚本生成覆盖率报告
./run_tests.sh --cov

# 或者直接使用 pytest
python -m pytest --cov=res_msg --cov-report=term --cov-report=html
```

覆盖率报告将生成在 `htmlcov/` 目录中。

### 测试目录结构

```
tests/
├── __init__.py     # 测试包初始化文件
├── conftest.py     # pytest 配置和共享 fixtures
├── test_cli.py     # CLI 功能测试
└── test_requests.py # HTTP 请求功能测试
```

## 持续集成
